==> sumus-6.3.1-sources.jar: io/intino/sumus/graph/editable/mold/block/EditableStamp.java <==
package io.intino.sumus.graph.editable.mold.block;

import io.intino.sumus.graph.*;
import io.intino.sumus.graph.Record;


public class EditableStamp extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
	protected io.intino.sumus.graph.functions.StampSaveEvent onSave;
	protected io.intino.sumus.graph.Mold.Block.Stamp _stamp;

	public EditableStamp(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public io.intino.sumus.graph.functions.StampSaveEvent.Refresh onSave(Record record, String value) {
		return onSave.save(record, value);
	}

	public java.lang.String label() {
		return _stamp.label();
	}

	public Object internalValue(Record record, String username) {
		return _stamp.internalValue(record, username);
	}

	public io.intino.sumus.graph.Mold.Block.Stamp.Layout layout() {
		return _stamp.layout();
	}

	public int height() {
		return _stamp.height();
	}

	public java.lang.String suffix() {
		return _stamp.suffix();
	}

	public java.lang.String defaultStyle() {
		return _stamp.defaultStyle();
	}

	public String style(Record record) {
		return _stamp.style(record);
	}

	public EditableStamp onSave(io.intino.sumus.graph.functions.StampSaveEvent value) {
		this.onSave = io.intino.tara.magritte.loaders.FunctionLoader.load(onSave, this, io.intino.sumus.graph.functions.StampSaveEvent.class);
		return (EditableStamp) this;
	}

	public EditableStamp label(java.lang.String value) {
		this._stamp.label(value);
		return (EditableStamp) this;
	}



	public EditableStamp layout(io.intino.sumus.graph.Mold.Block.Stamp.Layout value) {
		this._stamp.layout(value);
		return (EditableStamp) this;
	}

	public EditableStamp height(int value) {
		this._stamp.height(value);
		return (EditableStamp) this;
	}

	public EditableStamp suffix(java.lang.String value) {
		this._stamp.suffix(value);
		return (EditableStamp) this;
	}

	public EditableStamp defaultStyle(java.lang.String value) {
		this._stamp.defaultStyle(value);
		return (EditableStamp) this;
	}



	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		map.put("onSave", this.onSave != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.onSave)) : java.util.Collections.emptyList());
		return map;
	}

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("onSave")) this.onSave = io.intino.tara.magritte.loaders.FunctionLoader.load(values, this, io.intino.sumus.graph.functions.StampSaveEvent.class).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("onSave")) this.onSave = io.intino.tara.magritte.loaders.FunctionLoader.load(values.get(0), this, io.intino.sumus.graph.functions.StampSaveEvent.class);
	}

	@Override
	protected void sync$(io.intino.tara.magritte.Layer layer) {
		super.sync$(layer);
	    if (layer instanceof io.intino.sumus.graph.Mold.Block.Stamp) _stamp = (io.intino.sumus.graph.Mold.Block.Stamp) layer;

	}


	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}

==> sumus-6.3.3-sources.jar: io/intino/sumus/graph/editable/mold/block/EditableStamp.java <==
package io.intino.sumus.graph.editable.mold.block;

import io.intino.sumus.graph.*;
import io.intino.sumus.graph.Record;


public class EditableStamp extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
	protected io.intino.sumus.graph.functions.StampSaveEvent onSave;
	protected io.intino.sumus.graph.Mold.Block.Stamp _stamp;

	public EditableStamp(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public io.intino.sumus.graph.functions.StampSaveEvent.Refresh onSave(Record record, String value, String username) {
		return onSave.save(record, value, username);
	}

	public java.lang.String label() {
		return _stamp.label();
	}

	public Object internalValue(Record record, String username) {
		return _stamp.internalValue(record, username);
	}

	public io.intino.sumus.graph.Mold.Block.Stamp.Layout layout() {
		return _stamp.layout();
	}

	public int height() {
		return _stamp.height();
	}

	public java.lang.String suffix() {
		return _stamp.suffix();
	}

	public java.lang.String defaultStyle() {
		return _stamp.defaultStyle();
	}

	public String style(Record record) {
		return _stamp.style(record);
	}

	public EditableStamp onSave(io.intino.sumus.graph.functions.StampSaveEvent value) {
		this.onSave = io.intino.tara.magritte.loaders.FunctionLoader.load(onSave, this, io.intino.sumus.graph.functions.StampSaveEvent.class);
		return (EditableStamp) this;
	}

	public EditableStamp label(java.lang.String value) {
		this._stamp.label(value);
		return (EditableStamp) this;
	}



	public EditableStamp layout(io.intino.sumus.graph.Mold.Block.Stamp.Layout value) {
		this._stamp.layout(value);
		return (EditableStamp) this;
	}

	public EditableStamp height(int value) {
		this._stamp.height(value);
		return (EditableStamp) this;
	}

	public EditableStamp suffix(java.lang.String value) {
		this._stamp.suffix(value);
		return (EditableStamp) this;
	}

	public EditableStamp defaultStyle(java.lang.String value) {
		this._stamp.defaultStyle(value);
		return (EditableStamp) this;
	}



	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		map.put("onSave", this.onSave != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.onSave)) : java.util.Collections.emptyList());
		return map;
	}

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("onSave")) this.onSave = io.intino.tara.magritte.loaders.FunctionLoader.load(values, this, io.intino.sumus.graph.functions.StampSaveEvent.class).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("onSave")) this.onSave = io.intino.tara.magritte.loaders.FunctionLoader.load(values.get(0), this, io.intino.sumus.graph.functions.StampSaveEvent.class);
	}

	@Override
	protected void sync$(io.intino.tara.magritte.Layer layer) {
		super.sync$(layer);
	    if (layer instanceof io.intino.sumus.graph.Mold.Block.Stamp) _stamp = (io.intino.sumus.graph.Mold.Block.Stamp) layer;

	}


	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}
